/*

Copyright (C) 2009 Jaroslav Barton <djaara@djaara.net>

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

*/

#include "SensorAnimLabel.h"

#include <KStandardDirs>

#include <QWidget>
#include <QMovie>

/**
 * SensorAnimLabel - label with swipe/place animation.
 * @param sensor sensor type for selecting right animation
 * @param parent parent widget
 */
SensorAnimLabel::SensorAnimLabel(const QString& sensor, QWidget *parent) 
    : QLabel(parent),
      m_movie(0),
      m_sensor(sensor)
{
	if (m_sensor == "swipe") {
		m_movie = new QMovie(KStandardDirs::locate("data", "kfingermanager/pics/swipe.gif"));
	} else {
		// TODO get some animation for non-swipe sensors
		m_movie = new QMovie(KStandardDirs::locate("data", "kfingermanager/pics/swipe.gif"));
	}

	m_movie->start();
	m_movie->setPaused(true);
	setMovie(m_movie);
	setFixedSize(minimumSizeHint());
	clear();
}

/**
 * SensorAnimLabel destructor.
 */
SensorAnimLabel::~SensorAnimLabel() {
	m_movie->stop();
	clear();
	delete(m_movie);
}

/**
 * start - start animation playback.
 */
void SensorAnimLabel::start() {
	setMovie(m_movie);
	m_movie->setPaused(false);
}

/**
 * stop - stops animation playback
 */
void SensorAnimLabel::stop() {
	m_movie->setPaused(true);
	clear();
}

void SensorAnimLabel::loadMovie(const QString& s) {
	if (m_sensor == s) {
		return;
	} else {
		m_sensor = s;
	}

	stop();
	delete m_movie;
	
	if (m_sensor == i18n("swipe")) {
		m_movie = new QMovie(KStandardDirs::locate("data", "kgreet_fprintd/pics/swipe.gif"));
	} else {
		// TODO get some animation for non-swipe sensors
		m_movie = new QMovie(KStandardDirs::locate("data", "kgreet_fprintd/pics/swipe.gif"));
	}

	setMovie(m_movie);
    m_movie->start();
	m_movie->setPaused(true);
}

